import time

from machine import UART, Pin

uart = UART(2, baudrate=9600, tx=17, rx=16)

# Initialisation de la LED intégrée (souvent sur GPIO 2)
led = Pin(2, Pin.OUT)  # GPIO 2 pour la LED bleue intégrée

def send_at_command(command):
    uart.write(("AT" + command + "\r\n").encode())  # Envoie la commande AT au module LoRa
    time.sleep(0.3)  # Attendre la réponse du module
    while uart.any():
        response = uart.read().decode('utf-8')  # Lire la réponse
        print(response)

def blink_led(times, interval):
    for _ in range(times):
        led.value(1)  # Allumer la LED
        time.sleep(interval)  # Attendre un certain temps
        led.value(0)  # Eteindre la LED
        time.sleep(interval)  # Attendre un certain temps

def configure_lora(frequency, sf, bw, TXPR, RXPR, TX_power):
    send_at_command("")
    send_at_command("+MODE=TEST")
    # Configurer le module LoRa avec les paramètres donnés
    # send_at_command(f"+TEST=RFCFG,{frequency},SF{sf},{bw},{TXPR},{RXPR},{TX_power}")

def receive_uart():
    '''Polls the uart until all data is dequeued'''
    rxData=bytes()
    while uart.any()>0:
        rxData += uart.read(1)
        time.sleep(0.002)
    return rxData.decode('utf-8')

# Initialisation du module LoRa
blink_led(3, 0.5)  # Clignoter la LED 3 fois au démarrage
print("\n\nInitialisation du module LoRa-E5...\n")
configure_lora(868000000, 12, 125, 12, 15, 14)  # Configurer le module LoRa avec les paramètres souhaités
send_at_command("+TEST=RXLRPKT")  # Commencer la réception des paquets LoRa

led.value(1)  # Rallumer la LED après l'initialisation
print("Module LoRa-E5 initialisé. En attente de messages...\n")

while True:
    if uart.any():  # Si des données sont disponibles sur le port série
        message = receive_uart()  # Lire le message reçu
        print(f"Message reçu : {message}")
        data = message.split("\"")[1]
        print(f"Data : {data}\n")

        # Clignotement de la LED une fois pour indiquer la réception
        blink_led(1, 0.2)  # Clignoter la LED une fois
    time.sleep(0.01)
