import time
from machine import UART, Pin
import json
import requests

uart = UART(2, baudrate=9600, tx=17, rx=16)

# Initialisation de la LED intégrée (souvent sur GPIO 2)
led = Pin(2, Pin.OUT)  # GPIO 2 pour la LED bleue intégrée

def send_at_command(command):
    uart.write((command + "\r\n").encode())  # Envoie la commande AT au module LoRa
    time.sleep(0.3)  # Attendre la réponse du module
    while uart.any():
        response = uart.read().decode('utf-8')  # Lire la réponse
        print(response)

def blink_led(times, interval):
    for _ in range(times):
        led.value(1)  # Allumer la LED
        time.sleep(interval)  # Attendre un certain temps
        led.value(0)  # Eteindre la LED
        time.sleep(interval)  # Attendre un certain temps

def configure_lora(frequency, sf, bw, TXPR, RXPR, TX_power):
    send_at_command("AT")
    send_at_command("AT+MODE=TEST")
    # Configurer le module LoRa avec les paramètres donnés
    send_at_command(f"AT+TEST=RFCFG,{frequency},SF{sf},{bw},{TXPR},{RXPR},{TX_power}")

def send_to_sensor_community(value1, value2):
    # Envoi des données sur sensor community
    url = "https://api.sensor.community/v1/push-sensor-data/"
    headers = {
        "Content-Type": "application/json",
        "X-Pin": "1",
        "X-Sensor": "esp32-900881266"
    }
    data = {
        "software_version": "0.1",
        "sensordatavalues": [
            {"value_type": "P1", "value": str(value1)},
            {"value_type": "P2", "value": str(value2)}
        ]
    }

    response = requests.post(url, headers=headers, data, timeout=10)

    print(response.status_code)  # 201 = created
    print(response.text)

def try_receive():
    if uart.any():  # Si des données sont disponibles sur le port série
        message = uart.read().decode('utf-8').strip()  # Lire le message reçu
        print(f"Message reçu : {message}")

        # Clignotement de la LED une fois pour indiquer la réception
        led.value(0)  # Éteindre la LED
        time.sleep(0.1)  # Attendre un peu
        led.value(1)  # Rallumer la LED

        # Traitement du message reçu (extraction des valeurs P1 et P2)
        try:
            values = message.split(",")
            value1 = float(values[0])
            value2 = float(values[1])
            send_to_sensor_community(value1, value2)  # Envoyer les valeurs à Sensor Community
        except (IndexError, ValueError):
            print("Erreur lors de l'extraction des valeurs du message.")

# Initialisation du module LoRa
blink_led(3, 0.5)  # Clignoter la LED 3 fois au démarrage
print("Initialisation du module LoRa-E5...")
configure_lora(868000000, 12, 125, 12, 15, 14)  # Configurer le module LoRa avec les paramètres souhaités
send_at_command("AT+TEST=RXLRPKT")  # Commencer la réception des paquets LoRa

led.value(1)  # Rallumer la LED après l'initialisation
print("Module LoRa-E5 initialisé. En attente de messages...")

while True:
    try_receive()  # Essayer de recevoir un message
    time.sleep(0.1)  # Attendre un peu avant de vérifier à nouveau



